#!/usr/bin/python3
# -*- coding: utf-8 -*-
#
#
# ipaddress.py
#
# Copyright (C) 2011 Lorenzo Carbonell
# lorenzo.carbonell.cerezo@gmail.com
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
#

## install python-geoclue

import sys
if sys.version_info[0] == 3:	
	import http.client as httplib
else:
	import httplib
import string 
import json
from comun import read_from_url
from geocodeapi import get_inv_direction

def s2f(cadena):
	try:
		value = float(cadena)
	except:
		value = 0.0
	return value
	
def get_ip():
	try:
		conn = httplib.HTTPConnection("checkip.dyndns.org") 
		conn.request("GET","/index.html") 
		r1 = conn.getresponse() 
		conn.close() 
		if r1.status == 200:
			data1 = r1.read().decode()
			#startstr = string.find(data1,': ')+2 
			#endstr = string.find(data1,'</b') 
			if data1.find(': ')>-1 and data1.find('</b')>-1:
				startstr = data1.find(': ')+2
				endstr = data1.find('</b') 
				return data1[startstr:endstr]
			return None
		else:
			print('Error connecting to the server!! Check your internet connection')
			return None
	except Exception as e:
		print(e)
	return None

def get_value_from_xml(xml,parameter):
	start = '<%s>'%(parameter)
	end = '</%s>'%(parameter)
	startval = xml.find(start)
	endval = xml.find(end)
	if startval > -1:
		if endval > -1:
			startval += len(start)
			value = xml[startval:endval]
			return value
	return None
		
	
def get_current_location():
	try:
		read = read_from_url('http://geoip.ubuntu.com/lookup').decode()
		print(read)
		latitude = s2f((get_value_from_xml(read,'Latitude')))
		longitude = s2f((get_value_from_xml(read,'Longitude')))
		return latitude,longitude
	except Exception as e:
		print(e)
	return get_current_location2()
	
def get_current_location2():
	ip = get_ip()
	if ip:
		try:
			URL = "http://query.yahooapis.com/v1/public/yql?q=select%20latitude%2Clongitude%20from%20pidgets.geoip%20where%20ip%3D'$IP$'&format=json&env=http%3A%2F%2Fdatatables.org%2Falltables.env"
			URL = URL.replace('$IP$',ip)
			json_string = read_from_url(URL)
			parsed_json = json.loads(json_string.decode())
			lat = parsed_json['query']['results']['Result']['latitude']
			lng =  parsed_json['query']['results']['Result']['longitude']
			return s2f(lat),s2f(lng)
		except Exception as e:
			print(e)
	return 0.0, 0.0
	
def get_address_from_ip2():
	lat,lon = get_current_location()
	return get_inv_direction(lat,lon)['search_string']

def get_address_from_ip():
	try:
		read = read_from_url('http://geoip.ubuntu.com/lookup')
		ans = (get_value_from_xml(read.decode(),'City'))
		return ans
	except Exception as e:
		print(e)
	return ''

if __name__ == "__main__":
	print(get_ip())
	print(get_current_location())
	print(get_address_from_ip())
	print(get_current_location2())
